"""Google Search MCP Server Package.

This package provides a Model Context Protocol (MCP) server that enables
AI assistants to perform Google searches and receive structured results.

The server implements the MCP protocol and provides a single tool:
- google_search: Performs web searches using Google and returns formatted results

Usage:
    The server is designed to be run as a standalone MCP server:
    
    $ uvx mcp-server-googlesearch
    
    Or integrated with AI assistants like Claude Desktop through MCP configuration.
"""

from . import server
import asyncio

def main():
    """Main entry point for the MCP server.
    
    This function starts the Google Search MCP server and handles
    communication through stdin/stdout as required by the MCP protocol.
    """
    asyncio.run(server.main())

# Expose main components at package level
__all__ = ['main', 'server']
__version__ = '0.1.0'