"""Data models for Google Search MCP Server."""

from dataclasses import dataclass
from typing import Optional


@dataclass
class SearchResult:
    """Represents a single Google search result.
    
    Attributes:
        title: The title of the search result
        url: The URL of the search result
        description: The description/snippet of the search result
    """
    title: str
    url: str
    description: str
    
    def __post_init__(self):
        """Validate SearchResult fields after initialization."""
        if not self.title:
            raise ValueError("SearchResult title cannot be empty")
        if not self.url:
            raise ValueError("SearchResult URL cannot be empty")
        # Description can be empty, so we just ensure it's a string
        if self.description is None:
            self.description = ""
        if not isinstance(self.description, str):
            self.description = str(self.description)
    
    def to_formatted_string(self, index: int) -> str:
        """Format the search result as a numbered string for display.
        
        Args:
            index: The 1-based index number for this result
            
        Returns:
            Formatted string representation of the search result
        """
        return f"{index}. {self.title}\n   URL: {self.url}\n   Description: {self.description}"